pub struct Locations { /* private fields */ }Expand description
Location information in the State.
This resolves the input ranges of the events (see
State::input_range) into lines and columns with a SourceMap of the
Source. The source map is built on first use and
cached in the state. Consumers retrieve the resolved span of the current
event with current_span.
Implementations
Sourceimpl Locations
impl Locations
Sourcepub fn source_map(state: &mut State) -> Option<Arc<SourceMap>>
pub fn source_map(state: &mut State) -> Option<Arc<SourceMap>>
Returns the source map for the source in the state.
Returns None if the format does not provide the source.
Sourcepub fn current_span(state: &mut State) -> Option<Span>
pub fn current_span(state: &mut State) -> Option<Span>
Returns the span of the current event if the format provides it.