pub struct Position {
pub offset: usize,
pub line: usize,
pub column: usize,
}Expand description
Re-exported from deser, which counts positions the same way for errors. A position in the input.
Lines and columns are 1-based. Columns are counted in characters (bytes
that are not UTF-8 continuation bytes). This is how positions of errors
(see Error::line) are counted as well.
use deser::Position;
let pos = Position::of("[1,\n x]".as_bytes(), 6);
assert_eq!((pos.offset, pos.line, pos.column), (6, 2, 3));Fields
offset: usizeThe byte offset from the start of the input.
line: usizeThe line number (1-based).
column: usizeThe column number in characters (1-based).
Implementations